==> librenms-25.11.0v0.tgz: librenms/app/Http/Controllers/Device/Tabs/QosController.php <==
<?php

/**
 * QosController.php
 *
 * -Description-
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * @link       https://www.librenms.org
 *
 * @copyright  2024 Steven Wilton
 * @author     Steven Wilton <swilton@fluentit.com.au>
 */

namespace App\Http\Controllers\Device\Tabs;

use App\Models\Device;
use Illuminate\Http\Request;
use LibreNMS\Interfaces\UI\DeviceTab;

class QosController implements DeviceTab
{
    public function visible(Device $device): bool
    {
        return $device->qos()->whereNull('port_id')->whereNull('parent_id')->count() > 0;
    }

    public function slug(): string
    {
        return 'qos';
    }

    public function icon(): string
    {
        return 'fa-code-fork';
    }

    public function name(): string
    {
        return __('QoS');
    }

    public function data(Device $device, Request $request): array
    {
        $show = null;
        $vars = $request->vars;
        if ($vars) {
            $showvars = array_filter(explode('/', $vars), fn ($v) => str_starts_with($v, 'show='));
            if ($showvars) {
                $showvar = explode('=', $showvars[0]);
                $show = array_pop($showvar);
                if ($show) {
                    $show = intval($show);
                }
            }
        }

        return [
            'show' => $show,
        ];
    }
}

==> librenms-26.2.0p0v0.tgz: librenms/app/Http/Controllers/Device/Tabs/QosController.php <==
<?php

/**
 * QosController.php
 *
 * -Description-
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * @link       https://www.librenms.org
 *
 * @copyright  2024 Steven Wilton
 * @author     Steven Wilton <swilton@fluentit.com.au>
 */

namespace App\Http\Controllers\Device\Tabs;

use App\Models\Device;
use Illuminate\Http\Request;
use LibreNMS\Interfaces\UI\DeviceTab;

class QosController implements DeviceTab
{
    public function visible(Device $device): bool
    {
        return $device->qos()->whereNull('port_id')->whereNull('parent_id')->count() > 0;
    }

    public function slug(): string
    {
        return 'qos';
    }

    public function icon(): string
    {
        return 'fa-code-fork';
    }

    public function name(): string
    {
        return __('QoS');
    }

    public function data(Device $device, Request $request): array
    {
        $show = null;
        $vars = $request->vars;
        if ($vars) {
            $showvars = array_filter(explode('/', $vars), fn ($v) => str_starts_with((string) $v, 'show='));
            if ($showvars) {
                $showvar = explode('=', $showvars[0]);
                $show = array_pop($showvar);
                if ($show) {
                    $show = intval($show);
                }
            }
        }

        return [
            'show' => $show,
        ];
    }
}
